@@ -1,10 +1,10 @@
-# $Id: TextMatchTest.pm,v 1.4 2002/05/12 13:35:35 m_ilya Exp $
+# $Id: TextMatchTest.pm,v 1.6 2002/06/21 06:48:16 richardanderson Exp $
 
 package HTTP::WebTest::Plugin::TextMatchTest;
 
 =head1 NAME
 
-HTTP::WebTest::Plugin::TextMatchTest - Response body checks
+HTTP::WebTest::Plugin::TextMatchTest - Test the content of the HTTP response.
 
 =head1 SYNOPSIS
 
@@ -12,8 +12,8 @@ Not Applicable
 
 =head1 DESCRIPTION
 
-This plugin provides test parameters which allow to check response
-body.  It supports regexps and literal string searches.
+This plugin supports test on the content of the HTTP response.  You can test
+for the existence or non-existence of a literal string or a regular expression.
 
 =cut
 
@@ -40,14 +40,14 @@ C<no>
 
 =head2 text_forbid
 
-List of text strings that are forbidden to use exist in the returned
+List of text strings that are forbidden to exist in the returned
 page.
 
 See also the C<regex_forbid> and C<ignore_case> parameters.
 
 =head2 text_require
 
-List of text strings that are required to use exist in the returned
+List of text strings that are required to exist in the returned
 page.
 
 See also the C<regex_require> and C<ignore_case> parameters.
@@ -147,10 +147,10 @@ sub check_response {
 
 Copyright (c) 2000-2001 Richard Anderson.  All rights reserved.
 
-Copyright (c) 2001,2002 Ilya Martynov.  All rights reserved.
+Copyright (c) 2001-2002 Ilya Martynov.  All rights reserved.
 
-This module is free software.  It may be used, redistributed and/or
-modified under the terms of the Perl Artistic License.
+This program is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
